@@ -20,7 +20,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "appmenu.h"
-#include "client.h"
+#include "x11client.h"
 #include "workspace.h"
 #include <appmenu_interface.h>
 
@@ -112,6 +112,9 @@ void ApplicationMenu::slotMenuHidden(const QString &serviceName, const QDBusObje
 
 void ApplicationMenu::showApplicationMenu(const QPoint &p, AbstractClient *c, int actionId)
 {
+    if (!c->hasApplicationMenu()) {
+        return;
+    }
     m_appmenuInterface->showMenu(p.x(), p.y(), c->applicationMenuServiceName(), QDBusObjectPath(c->applicationMenuObjectPath()), actionId);
 }
 
