@@ -17,7 +17,7 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
-#include <QtTest/QtTest>
+#include <QtTest>
 #include <QLoggingCategory>
 #include <QX11Info>
 
