@@ -176,7 +176,7 @@ void TestBuiltInEffectLoader::testKnownEffects()
     KWin::BuiltInEffectLoader loader;
     QStringList result = loader.listOfKnownEffects();
     QCOMPARE(result.size(), expectedEffects.size());
-    qSort(result);
+    std::sort(result.begin(), result.end());
     for (int i = 0; i < expectedEffects.size(); ++i) {
         QCOMPARE(result.at(i), expectedEffects.at(i));
     }
@@ -357,7 +357,7 @@ void TestBuiltInEffectLoader::testLoadEffect()
     loader.setConfig(config);
 
     qRegisterMetaType<KWin::Effect*>();
-    QSignalSpy spy(&loader, SIGNAL(effectLoaded(KWin::Effect*,QString)));
+    QSignalSpy spy(&loader, &KWin::BuiltInEffectLoader::effectLoaded);
     // connect to signal to ensure that we delete the Effect again as the Effect doesn't have a parent
     connect(&loader, &KWin::BuiltInEffectLoader::effectLoaded,
         [&name](KWin::Effect *effect, const QString &effectName) {
@@ -446,7 +446,7 @@ void TestBuiltInEffectLoader::testLoadBuiltInEffect()
     loader.setConfig(config);
 
     qRegisterMetaType<KWin::Effect*>();
-    QSignalSpy spy(&loader, SIGNAL(effectLoaded(KWin::Effect*,QString)));
+    QSignalSpy spy(&loader, &KWin::BuiltInEffectLoader::effectLoaded);
     // connect to signal to ensure that we delete the Effect again as the Effect doesn't have a parent
     connect(&loader, &KWin::BuiltInEffectLoader::effectLoaded,
         [&name](KWin::Effect *effect, const QString &effectName) {
@@ -511,7 +511,7 @@ void TestBuiltInEffectLoader::testLoadAllEffects()
     loader.setConfig(config);
 
     qRegisterMetaType<KWin::Effect*>();
-    QSignalSpy spy(&loader, SIGNAL(effectLoaded(KWin::Effect*,QString)));
+    QSignalSpy spy(&loader, &KWin::BuiltInEffectLoader::effectLoaded);
     // connect to signal to ensure that we delete the Effect again as the Effect doesn't have a parent
     connect(&loader, &KWin::BuiltInEffectLoader::effectLoaded,
         [](KWin::Effect *effect) {
@@ -557,7 +557,7 @@ void TestBuiltInEffectLoader::testLoadAllEffects()
         QCOMPARE(list.size(), 2);
         loadedEffects << list.at(1).toString();
     }
-    qSort(loadedEffects);
+    std::sort(loadedEffects.begin(), loadedEffects.end());
     QCOMPARE(loadedEffects.at(0), QStringLiteral("kscreen"));
     QCOMPARE(loadedEffects.at(1), QStringLiteral("mouseclick"));
 }
